@@ -1,13 +1,18 @@
 from helper import timestamp_to_datetime
 
+
 class ApiModel(object):
 
     @classmethod
     def object_from_dictionary(cls, entry):
         # make dict keys all strings
-        entry_str_dict = dict([(str(key), value) for key,value in entry.items()])
+        entry_str_dict = dict([(str(key), value) for key, value in entry.items()])
         return cls(**entry_str_dict)
 
+    def __repr__(self):
+        return unicode(self).encode('utf8')
+
+
 class Image(ApiModel):
 
     def __init__(self, url, width, height):
@@ -15,30 +20,37 @@ class Image(ApiModel):
         self.height = height
         self.width = width
 
+    def __unicode__(self):
+        return "Image: %s" % self.url
+
+
 class Media(ApiModel):
 
     def __init__(self, id=None, **kwargs):
         self.id = id
-        for key,value in kwargs.iteritems():
+        for key, value in kwargs.iteritems():
             setattr(self, key, value)
 
     def get_standard_resolution_url(self):
         return self.images['standard_resolution'].url
 
+    def __unicode__(self):
+        return "Media: %s" % self.id
+
     @classmethod
     def object_from_dictionary(cls, entry):
         new_media = Media(id=entry['id'])
 
         new_media.user = User.object_from_dictionary(entry['user'])
         new_media.images = {}
-        for version,version_info in entry['images'].iteritems():
+        for version, version_info in entry['images'].iteritems():
             new_media.images[version] = Image.object_from_dictionary(version_info)
 
         if 'user_has_liked' in entry:
             new_media.user_has_liked = entry['user_has_liked']
         new_media.like_count = entry['likes']['count']
         new_media.likes = []
-        if entry['likes'].has_key('data'):
+        if 'data' in entry['likes']:
             for like in entry['likes']['data']:
                 new_media.likes.append(User.object_from_dictionary(like))
 
@@ -47,20 +59,19 @@ class Media(ApiModel):
         for comment in entry['comments']['data']:
             new_media.comments.append(Comment.object_from_dictionary(comment))
 
-        new_media.caption = None
-        if entry['caption']:
-            new_media.caption = Caption.object_from_dictionary(entry['caption'])
-
         new_media.created_time = timestamp_to_datetime(entry['created_time'])
 
-        if entry['location'] and entry.has_key('id'):
+        if entry['location'] and 'id' in entry:
             new_media.location = Location.object_from_dictionary(entry['location'])
 
         new_media.caption = None
         if entry['caption']:
             new_media.caption = Comment.object_from_dictionary(entry['caption'])
 
-        new_media.tags = entry['tags']
+        if entry['tags']:
+            new_media.tags = []
+            for tag in entry['tags']:
+                new_media.tags.append(Tag.object_from_dictionary({'name': tag}))
 
         new_media.link = entry['link']
 
@@ -68,18 +79,20 @@ class Media(ApiModel):
 
         return new_media
 
+
 class Tag(ApiModel):
     def __init__(self, name, **kwargs):
         self.name = name
-        for key,value in kwargs.iteritems():
+        for key, value in kwargs.iteritems():
             setattr(self, key, value)
 
-    def __str__(self):
-        return "Tag %s" % self.name
+    def __unicode__(self):
+        return "Tag: %s" % self.name
+
 
 class Comment(ApiModel):
     def __init__(self, *args, **kwargs):
-        for key,value in kwargs.iteritems():
+        for key, value in kwargs.iteritems():
             setattr(self, key, value)
 
     @classmethod
@@ -88,23 +101,25 @@ class Comment(ApiModel):
         text = entry['text']
         created_at = timestamp_to_datetime(entry['created_time'])
         id = entry['id']
-        return cls(id=id, user=user, text=text, created_at=created_at)
+        return Comment(id=id, user=user, text=text, created_at=created_at)
 
     def __unicode__(self):
-        return "%s said \"%s\"" % (self.user.username, self.message)
+        return "Comment: %s said \"%s\"" % (self.user.username, self.text)
 
-class Caption(Comment):
-    pass
 
 class Point(ApiModel):
     def __init__(self, latitude, longitude):
         self.latitude = latitude
         self.longitude = longitude
 
+    def __unicode__(self):
+        return "Point: (%s, %s)" % (self.latitude, self.longitude)
+
+
 class Location(ApiModel):
     def __init__(self, id, *args, **kwargs):
         self.id = id
-        for key,value in kwargs.iteritems():
+        for key, value in kwargs.iteritems():
             setattr(self, key, value)
 
     @classmethod
@@ -113,20 +128,25 @@ class Location(ApiModel):
         if 'latitude' in entry:
             point = Point(entry.get('latitude'),
                           entry.get('longitude'))
-        location = cls(entry.get('id', 0),
+        location = Location(entry.get('id', 0),
                        point=point,
                        name=entry.get('name', ''))
         return location
 
+    def __unicode__(self):
+        return "Location: %s (%s)" % (self.id, self.point)
+
+
 class User(ApiModel):
 
     def __init__(self, id, *args, **kwargs):
         self.id = id
-        for key,value in kwargs.iteritems():
+        for key, value in kwargs.iteritems():
             setattr(self, key, value)
 
-    def __str__(self):
-        return "User %s" % self.username
+    def __unicode__(self):
+        return "User: %s" % self.username
+
 
 class Relationship(ApiModel):
 
@@ -134,5 +154,3 @@ class Relationship(ApiModel):
         self.incoming_status = incoming_status
         self.outgoing_status = outgoing_status
         self.target_user_is_private = target_user_is_private
-
-
