@@ -3,6 +3,7 @@ import urllib
 from httplib2 import Http
 import mimetypes
 
+
 class OAuth2AuthExchangeError(Exception):
     def __init__(self, description):
         self.description = description
@@ -10,6 +11,7 @@ class OAuth2AuthExchangeError(Exception):
     def __str__(self):
         return self.description
 
+
 class OAuth2API(object):
     host = None
     base_path = None
@@ -30,26 +32,27 @@ class OAuth2API(object):
 
     def get_authorize_url(self, scope=None):
         req = OAuth2AuthExchangeRequest(self)
-        return req.get_authorize_url(scope = scope)
+        return req.get_authorize_url(scope=scope)
 
     def get_authorize_login_url(self, scope=None):
         """ scope should be a tuple or list of requested scope access levels """
         req = OAuth2AuthExchangeRequest(self)
-        return req.get_authorize_login_url(scope = scope)
+        return req.get_authorize_login_url(scope=scope)
 
     def exchange_code_for_access_token(self, code):
         req = OAuth2AuthExchangeRequest(self)
-        return req.exchange_for_access_token(code = code)
+        return req.exchange_for_access_token(code=code)
 
     def exchange_user_id_for_access_token(self, user_id):
         req = OAuth2AuthExchangeRequest(self)
-        return req.exchange_for_access_token(user_id = user_id)
+        return req.exchange_for_access_token(user_id=user_id)
 
     def exchange_xauth_login_for_access_token(self, username, password, scope=None):
         """ scope should be a tuple or list of requested scope access levels """
         req = OAuth2AuthExchangeRequest(self)
-        return req.exchange_for_access_token(username = username, password = password,
-                                             scope = scope)
+        return req.exchange_for_access_token(username=username, password=password,
+                                             scope=scope)
+
 
 class OAuth2AuthExchangeRequest(object):
     def __init__(self, api):
@@ -62,7 +65,7 @@ class OAuth2AuthExchangeRequest(object):
             "redirect_uri": self.api.redirect_uri
         }
         if scope:
-            client_params.update(scope = ' '.join(scope))
+            client_params.update(scope=' '.join(scope))
         url_params = urllib.urlencode(client_params)
         return "%s?%s" % (self.api.authorize_url, url_params)
 
@@ -76,22 +79,22 @@ class OAuth2AuthExchangeRequest(object):
         if code:
             client_params.update(code=code)
         elif username and password:
-            client_params.update(username = username,
-                                 password = password,
-                                 grant_type = "password")
+            client_params.update(username=username,
+                                 password=password,
+                                 grant_type="password")
             if scope:
-                client_params.update(scope = ' '.join(scope))
+                client_params.update(scope=' '.join(scope))
         elif user_id:
-            client_params.update(user_id = user_id)
+            client_params.update(user_id=user_id)
         return urllib.urlencode(client_params)
 
     def get_authorize_url(self, scope=None):
-        return self._url_for_authorize(scope = scope)
+        return self._url_for_authorize(scope=scope)
 
     def get_authorize_login_url(self, scope=None):
         http_object = Http(disable_ssl_certificate_validation=True)
 
-        url = self._url_for_authorize(scope = scope)
+        url = self._url_for_authorize(scope=scope)
         response, content = http_object.request(url)
         if response['status'] != '200':
             raise OAuth2AuthExchangeError("The server returned a non-200 response for URL %s" % url)
@@ -99,7 +102,7 @@ class OAuth2AuthExchangeRequest(object):
         return redirected_to
 
     def exchange_for_access_token(self, code=None, username=None, password=None, scope=None, user_id=None):
-        data = self._data_for_exchange(code, username, password, scope = scope, user_id = user_id)
+        data = self._data_for_exchange(code, username, password, scope=scope, user_id=user_id)
         http_object = Http(disable_ssl_certificate_validation=True)
         url = self.api.access_token_url
         response, content = http_object.request(url, method="POST", body=data)
@@ -172,7 +175,7 @@ class OAuth2Request(object):
         for field in files:
             lines.extend(encode_file(field))
         lines.extend(("--%s--" % (boundary), ""))
-        body = "\r\n".join (lines)
+        body = "\r\n".join(lines)
 
         headers = {"Content-Type": "multipart/form-data; boundary=" + boundary,
                    "Content-Length": str(len(body))}
@@ -195,7 +198,7 @@ class OAuth2Request(object):
             else:
                 url = self._full_url_with_params(path, params, include_secret)
         else:
-            body, headers = encode_multipart(params, params['files'])
+            body, headers = self._encode_multipart(params, params['files'])
             url = self._full_url(path)
 
         return url, method, body, headers
@@ -203,6 +206,6 @@ class OAuth2Request(object):
     def make_request(self, url, method="GET", body=None, headers=None):
         headers = headers or {}
         if not 'User-Agent' in headers:
-            headers.update({"User-Agent":"%s Python Client" % self.api.api_name})
+            headers.update({"User-Agent": "%s Python Client" % self.api.api_name})
         http_obj = Http(disable_ssl_certificate_validation=True)
         return http_obj.request(url, method, body=body, headers=headers)
